@@ -5,7 +5,7 @@ from database_utils import File_Expt
 import sqlalchemy
 
 ##### PATH #####
-def find_path(session,file_expt,path_name,top_name):
+def find_path(session,file_expt,path_name,top_name,propagated_values):
     setattr(file_expt,'path',path_name)
     session.add(file_expt)
     session.commit()
@@ -19,7 +19,7 @@ def intersection(paths_dict,diag_tree_desc, diag_tree_desc_final):
     file_expt = File_Expt(diag_tree_desc)
 
     top_name='data_pointers'
-    database_utils.create_database_from_tree(session,file_expt,paths_dict[top_name],top_name,find_path,'')
+    database_utils.create_database_from_tree(session,file_expt,paths_dict[top_name],top_name,{},find_path,'')
 
     #Step one: find all the center / model tuples with all the requested variables
     model_list=session.query(
